@@ -7,7 +7,7 @@ Attean::API::Model - RDF Model
 
 =head1 VERSION
 
-This document describes Attean::API::Model version 0.001_01
+This document describes Attean::API::Model version 0.002_01
 
 =head1 DESCRIPTION
 
@@ -295,13 +295,20 @@ package Attean::API::MutableModel 0.001 {
 }
 
 
-package Attean::API::CacheableModel 0.001 {
+package Attean::API::ETagCacheableModel 0.001 {
 	use Moo::Role;
 	
 	requires 'etag_value_for_quads';
 }
 
 
+package Attean::API::TimeCacheableModel 0.001 {
+	use Moo::Role;
+	
+	requires 'mtime_for_quads';
+}
+
+
 package Attean::API::BulkUpdatableModel 0.001 {
 	use Moo::Role;
 	
